=================
wagtail_formation
=================


.. image:: https://img.shields.io/pypi/v/wagtail_formation.svg
        :target: https://pypi.python.org/pypi/wagtail_formation

.. image:: https://img.shields.io/travis/mwesterhof/wagtail_formation.svg
        :target: https://travis-ci.com/mwesterhof/wagtail_formation

.. image:: https://readthedocs.org/projects/wagtail-formation/badge/?version=latest
        :target: https://wagtail-formation.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Build forms from wagtail blocks


* Free software: MIT license
* Documentation: https://wagtail-formation.readthedocs.io.


Features
--------

* Implement truly dynamic forms in a wagtail CMS
* Technical details are handled by the developer, everything else is content
* Form content is as dynamic as page content can be, fully leveraging the power of StreamBlocks
* Forms can be created on a page itself, or reused accross multiple pages

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
